pub enum FocusState {
Inactive,
ActiveParent,
Active,
Captured,
}Expand description
Focus state for a registered focus node.
Use this to render focus-dependent UI and distinguish between the primary focused target and its focused ancestors.
Examples
use tessera_ui::FocusState;
assert!(!FocusState::Inactive.has_focus());
assert!(FocusState::ActiveParent.has_focus());
assert!(FocusState::Active.is_focused());
assert!(FocusState::Captured.is_captured());Variants
Inactive
The node is not participating in the active focus path.
ActiveParent
A descendant of this node currently holds focus.
Active
This node currently holds focus.
Captured
This node currently holds captured focus.
Implementations
Sourceimpl FocusState
impl FocusState
Sourcepub fn is_focused(self) -> bool
pub fn is_focused(self) -> bool
Returns true when this node is the primary focused node.
Sourcepub fn is_captured(self) -> bool
pub fn is_captured(self) -> bool
Returns true when this node has captured focus.