pub struct FocusManager;Expand description
Owner-scoped focus manager for traversal and forced clear operations.
Use the focus manager to trigger application-level traversal without storing a specific scope or requester.
Examples
use tessera_ui::FocusManager;
let _manager = FocusManager::current();Implementations
Sourceimpl FocusManager
impl FocusManager
Sourcepub fn clear_focus(self, force: bool)
pub fn clear_focus(self, force: bool)
Clears the current focus. Set force to true to break captured focus.
Sourcepub fn move_focus(self, direction: FocusDirection) -> bool
pub fn move_focus(self, direction: FocusDirection) -> bool
Moves focus in the requested direction.