pub struct FocusRevealRequest {
pub target_rect: PxRect,
pub viewport_rect: PxRect,
}Expand description
A request for scroll containers to reveal a focused rectangle.
Fields
target_rect: PxRectThe absolute rectangle of the focused target.
viewport_rect: PxRectThe absolute visible viewport of the current reveal container.